diff --git a/python_binding/graph/pybind_Node.cpp b/python_binding/graph/pybind_Node.cpp
index 7993282fbe072e85513b96aeaa6766e26afe1c18..6c5be2b887fe9b65e85fe8fbe9cbcdff7dc1dc15 100644
--- a/python_binding/graph/pybind_Node.cpp
+++ b/python_binding/graph/pybind_Node.cpp
@@ -119,11 +119,11 @@ void init_Node(py::module& m) {
 
     .def("input", &Node::input, py::arg("in_id"),
     R"mydelimiter(
-    Get the parent Node and the associated output index connected to the i-th input of the current Node.
+    Get the parent Node and the associated output index connected to the specified input of the current Node.
 
     :param in_id: input index of the current Node object.
     :type in_id: int
     :return: i-th connection. When an input is not linked to any parent, the default value is (None, default_index)
     :rtype: tuple[Node, int]
     )mydelimiter")
 
@@ -131,7 +131,7 @@ void init_Node(py::module& m) {
     R"mydelimiter(
     Get, for each output of the Node, a list of the children Node and the associated input index connected to it.
 
-    :return: List of a list of connections. When an outut is not linked to any child,  its list a empty.
+    :return: List of a list of connections. When an output is not linked to any child,  its list is empty.
     :rtype: list[list[tuple[Node, int]]]
     )mydelimiter")
 
@@ -141,7 +141,8 @@ void init_Node(py::module& m) {
 
     :param out_id: input index of the current Node object.
     :type out_id: int
-    :return: i-th connection. When an input is not linked to any parent, the default value is (None, default_index)
+    :return: List of Nodes and their inputs that are connected to the specified output.
+    When an input is not linked to any parent, the default value is (None, default_index)
     :rtype: list[tuple[Node, int]]
     )mydelimiter")
@@ -119,11 +119,11 @@ void init_Node(py::module& m) {
     :param in_id: input index of the current Node object.
     :type in_id: int
-    :return: i-th connection. When an input is not linked to any parent, the default value is (None, default_index)
+    :return: The parent Node and the corresponding output index of the specified input of the current Node. When an input is not linked to any parent, the default value is (None, default_index)
     :rtype: tuple[Node, int]
     )mydelimiter")